@@ -6,8 +6,10 @@ import inspect
 
 
 def gql(f):
+    """Unused"""
+
     def wrapper(*args, **kwargs):
-        print("hehehe", inspect.signature(f))
+        print("signature", inspect.signature(f))
         print("args", args, "kwargs", kwargs)
         return f(*args, **kwargs)
 
