@@ -121,6 +121,7 @@ ResolverTempType = T.TypeVar("ResolverTempType", bound="Resolver")
 
 class Node(BaseModel):
     _cache: CacheManager = PrivateAttr(default_factory=CacheManager)
+    _used_resolver: ResolverType = PrivateAttr(None)
 
     id: str
 
@@ -181,7 +182,7 @@ class Node(BaseModel):
                     return True
         return False
 
-    def resolve(
+    async def resolve(
         self,
         name: str,
         resolver: T.Optional[ResolverTempType],
@@ -207,7 +208,7 @@ class Node(BaseModel):
                 self.cache.remove(name)
         if not self.cache.exists(name):
             setattr(root_resolver.edges, name, resolver)
-            obj = root_resolver._get(kwargs_d={"id": self.id})
+            obj = await root_resolver._get(kwargs_d={"id": self.id})
             self.cache.replace(key=name, cache=obj.cache.get(name))
         return self.cache.get_val(name)
 
@@ -220,6 +221,27 @@ class Node(BaseModel):
     def resolver(cls) -> ResolverType:
         return cls.Dgraph.resolver()
 
+    """ADD REFRESH BEFORE ADDING ADD"""
+
+    async def refresh(self: NodeModel) -> NodeModel:
+        """ In future, just replace all fields including cache w new ones... """
+        return await self._used_resolver._get({"id": self.id})
+
+    def add_old(self: NodeModel, upsert: bool = False) -> NodeModel:
+        # TODO
+        """Include options to add relationships -> like taught_by: {"username": "malia"}... autogen this!"""
+        """Must include a refresh option too, no?"""
+        input = self.dict(exclude={"id"})  # actually do INPUT type when this is ready
+        # return exact obj w current resolver configs
+
+    def update(self: NodeModel) -> NodeModel:
+        # TODO
+        pass
+
+    def delete(self) -> bool:
+        # TODO
+        pass
+
 
 from .resolver import Resolver
 
