@@ -3,7 +3,7 @@ import typing as T
 import json
 from pydantic import BaseModel, Field
 from fastapi.encoders import jsonable_encoder
-from .execute import execute, execute_async
+from . import execute
 from .gql import GQLException
 from .node import Node, Params
 
@@ -64,18 +64,26 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         print(s)
         return s
 
-    async def query_async(self) -> T.List[NodeType]:
+    def make_add_query_str(self) -> str:
+        s = f"{{ {self.node.Dgraph.payload_node_name}{self.params_and_fields()} }}"
+        return s
+
+    def make_add_mutation_str(self) -> str:
+        typename = self.node.Dgraph.typename
+        s = f"""
+            mutation Add{typename}($input: [Add{typename}Input!]!, $upsert: Boolean) {{
+                add{typename}(input: $input, upsert: $upsert) {self.make_add_query_str()}
+            }}
+        """
+        return s
+
+    async def query(self) -> T.List[NodeType]:
         s = self.make_query_query_str()
-        lst: T.List[dict] = (await execute_async(query_str=s))["data"][
+        lst: T.List[dict] = (await execute.gql(query_str=s))["data"][
             self.query_query_name()
         ]
         return [self.parse_obj_nested(d) for d in lst]
 
-    def query(self) -> T.List[NodeType]:
-        s = self.make_query_query_str()
-        lst: T.List[dict] = execute(query_str=s)["data"][self.query_query_name()]
-        return [self.parse_obj_nested(d) for d in lst]
-
     def parse_obj_nested(self, gql_d: dict) -> NodeType:
         node: NodeType = self.node.parse_obj(gql_d)
         other_fields = set(gql_d.keys()) - set(node.__fields__.keys()) - {"__typename"}
@@ -93,18 +101,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                 )
                 value_to_save = val
             node.cache.add(key=field, resolver=resolver, val=value_to_save, gql_d=gql_d)
+        node._used_resolver = self
         return node
 
-    def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
+    async def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
         s = self.make_get_query_str(kwargs_d=kwargs_d)
-        obj = execute(query_str=s)["data"][self.get_query_name()]
-        if obj:
-            return self.parse_obj_nested(obj)
-        return None
-
-    async def _get_async(self, kwargs_d: dict) -> T.Optional[NodeType]:
-        s = self.make_get_query_str(kwargs_d=kwargs_d)
-        obj = (await execute_async(query_str=s))["data"][self.get_query_name()]
+        obj = (await execute.gql(query_str=s))["data"][self.get_query_name()]
         if obj:
             return self.parse_obj_nested(obj)
         return None
